import pytest

class TestDemo:

    def test_demo_1(self):
        print('\ntest_demo_1')
        pass

    def test_demo_2(self):
        print('test_demo_2')
        pass

    def test_demo_3(self):
        print('test_demo_3')
        pass

    def test_demo_4(self):
        print('test_demo_4')
        pass